# RAi, machine learning solutions in radiotherapy
# Copyright (C) 2021-2022 Radiotherapy AI Holdings Pty Ltd

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable = invalid-name,

from enum import Enum


class TG263(str, Enum):
    """TG263 naming.

    Based on the spreadsheet downloadable from
    https://www.aapm.org/pubs/reports/rpt_263_supplemental/TG263_Nomenclature_Worksheet_20170815.xls
    """

    A_Aorta = "A_Aorta"
    A_Aorta_Asc = "A_Aorta_Asc"
    A_Brachiocephls = "A_Brachiocephls"
    A_Carotid = "A_Carotid"
    A_Carotid_L = "A_Carotid_L"
    A_Carotid_R = "A_Carotid_R"
    A_Celiac = "A_Celiac"
    A_Coronary = "A_Coronary"
    A_Coronary_L = "A_Coronary_L"
    A_Coronary_R = "A_Coronary_R"
    A_Femoral_Cflx_L = "A_Femoral_Cflx_L"
    A_Femoral_Cflx_R = "A_Femoral_Cflx_R"
    A_Femoral_L = "A_Femoral_L"
    A_Femoral_R = "A_Femoral_R"
    A_Humeral_Cflx_L = "A_Humeral_Cflx_L"
    A_Humeral_Cflx_R = "A_Humeral_Cflx_R"
    A_Humeral_L = "A_Humeral_L"
    A_Humeral_R = "A_Humeral_R"
    A_Hypophyseal_I = "A_Hypophyseal_I"
    A_Hypophyseal_S = "A_Hypophyseal_S"
    A_Iliac_Cflx_L = "A_Iliac_Cflx_L"
    A_Iliac_Cflx_R = "A_Iliac_Cflx_R"
    A_Iliac_Ext_L = "A_Iliac_Ext_L"
    A_Iliac_Ext_R = "A_Iliac_Ext_R"
    A_Iliac_Int_L = "A_Iliac_Int_L"
    A_Iliac_Int_R = "A_Iliac_Int_R"
    A_Iliac_L = "A_Iliac_L"
    A_Iliac_R = "A_Iliac_R"
    A_LAD = "A_LAD"
    A_Mesenteric_I = "A_Mesenteric_I"
    A_Mesenteric_S = "A_Mesenteric_S"
    A_Pulmonary = "A_Pulmonary"
    A_Subclavian = "A_Subclavian"
    A_Subclavian_L = "A_Subclavian_L"
    A_Subclavian_R = "A_Subclavian_R"
    A_Vertebral = "A_Vertebral"
    A_Vertebral_L = "A_Vertebral_L"
    A_Vertebral_R = "A_Vertebral_R"
    Acetabulum_L = "Acetabulum_L"
    Acetabulum_R = "Acetabulum_R"
    Acetabulums = "Acetabulums"
    AirWay_Dist = "AirWay_Dist"
    AirWay_Prox = "AirWay_Prox"
    Anus = "Anus"
    Appendix = "Appendix"
    Arytenoid = "Arytenoid"
    Arytenoid_L = "Arytenoid_L"
    Arytenoid_R = "Arytenoid_R"
    Atrium = "Atrium"
    Atrium_L = "Atrium_L"
    Atrium_R = "Atrium_R"
    Bag_Bowel = "Bag_Bowel"
    Bag_Ostomy = "Bag_Ostomy"
    BileDuct_Common = "BileDuct_Common"
    Bladder = "Bladder"
    Bladder_Wall = "Bladder_Wall"
    Bladder_CTV = "Bladder-CTV"
    Body = "Body"
    Body_PTV = "Body-PTV"
    Bolus = "Bolus"
    Bolus_xxmm = "Bolus_xxmm"
    Bone = "Bone"
    Bone_Ethmoid = "Bone_Ethmoid"
    Bone_Frontal = "Bone_Frontal"
    Bone_Hyoid = "Bone_Hyoid"
    Bone_Ilium = "Bone_Ilium"
    Bone_Ilium_L = "Bone_Ilium_L"
    Bone_Ilium_R = "Bone_Ilium_R"
    Bone_Incus = "Bone_Incus"
    Bone_Incus_L = "Bone_Incus_L"
    Bone_Incus_R = "Bone_Incus_R"
    Bone_Ischium_L = "Bone_Ischium_L"
    Bone_Ischium_R = "Bone_Ischium_R"
    Bone_Lacrimal = "Bone_Lacrimal"
    Bone_Lacrimal_L = "Bone_Lacrimal_L"
    Bone_Lacrimal_R = "Bone_Lacrimal_R"
    Bone_Mandible = "Bone_Mandible"
    Bone_Mastoid = "Bone_Mastoid"
    Bone_Mastoid_L = "Bone_Mastoid_L"
    Bone_Mastoid_R = "Bone_Mastoid_R"
    Bone_Nasal = "Bone_Nasal"
    Bone_Nasal_L = "Bone_Nasal_L"
    Bone_Nasal_R = "Bone_Nasal_R"
    Bone_Occipital = "Bone_Occipital"
    Bone_Palatine = "Bone_Palatine"
    Bone_Palatine_L = "Bone_Palatine_L"
    Bone_Palatine_R = "Bone_Palatine_R"
    Bone_Parietal = "Bone_Parietal"
    Bone_Parietal_L = "Bone_Parietal_L"
    Bone_Parietal_R = "Bone_Parietal_R"
    Bone_Pelvic = "Bone_Pelvic"
    Bone_Pelvic_L = "Bone_Pelvic_L"
    Bone_Pelvic_R = "Bone_Pelvic_R"
    Bone_Sphenoid = "Bone_Sphenoid"
    Bone_Temporal = "Bone_Temporal"
    Bone_Temporal_L = "Bone_Temporal_L"
    Bone_Temporal_R = "Bone_Temporal_R"
    Bone_Zygomatic_L = "Bone_Zygomatic_L"
    Bone_Zygomatic_R = "Bone_Zygomatic_R"
    Bone_Zygomatics = "Bone_Zygomatics"
    BoneMarrow = "BoneMarrow"
    BoneMarrow_Act = "BoneMarrow_Act"
    Boost = "Boost"
    Bowel = "Bowel"
    Bowel_Large = "Bowel_Large"
    Bowel_Small = "Bowel_Small"
    BrachialPlex_L = "BrachialPlex_L"
    BrachialPlex_R = "BrachialPlex_R"
    BrachialPlexs = "BrachialPlexs"
    Brain = "Brain"
    Brain_CTV = "Brain-CTV"
    Brain_GTV = "Brain-GTV"
    Brain_PTV = "Brain-PTV"
    Brainstem = "Brainstem"
    Brainstem_Core = "Brainstem_Core"
    Brainstem_PRV = "Brainstem_PRV"
    Brainstem_PRVxx = "Brainstem_PRVxx"
    Brainstem_Surf = "Brainstem_Surf"
    Breast_L = "Breast_L"
    Breast_R = "Breast_R"
    Breasts = "Breasts"
    Bronchus = "Bronchus"
    Bronchus_L = "Bronchus_L"
    Bronchus_Main = "Bronchus_Main"
    Bronchus_Main_L = "Bronchus_Main_L"
    Bronchus_Main_R = "Bronchus_Main_R"
    Bronchus_PRVxx = "Bronchus_PRVxx"
    Bronchus_R = "Bronchus_R"
    Canal_Anal = "Canal_Anal"
    Carina = "Carina"
    Cartlg_Thyroid = "Cartlg_Thyroid"
    CaudaEquina = "CaudaEquina"
    Cavernosum = "Cavernosum"
    Cavity_Nasal = "Cavity_Nasal"
    Cavity_Oral = "Cavity_Oral"
    Cecum = "Cecum"
    Cerebellum = "Cerebellum"
    Cerebrum = "Cerebrum"
    Cerebrum_L = "Cerebrum_L"
    Cerebrum_R = "Cerebrum_R"
    Cervix = "Cervix"
    Chestwall = "Chestwall"
    Chestwall_L = "Chestwall_L"
    Chestwall_R = "Chestwall_R"
    Cist_Pontine = "Cist_Pontine"
    Cist_Suprasellar = "Cist_Suprasellar"
    Clavicle_L = "Clavicle_L"
    Clavicle_R = "Clavicle_R"
    CN_III = "CN_III"
    CN_III_L = "CN_III_L"
    CN_III_R = "CN_III_R"
    CN_IX = "CN_IX"
    CN_IX_L = "CN_IX_L"
    CN_IX_R = "CN_IX_R"
    CN_V = "CN_V"
    CN_V_L = "CN_V_L"
    CN_V_R = "CN_V_R"
    CN_VI = "CN_VI"
    CN_VI_L = "CN_VI_L"
    CN_VI_R = "CN_VI_R"
    CN_VII = "CN_VII"
    CN_VII_L = "CN_VII_L"
    CN_VII_R = "CN_VII_R"
    CN_VIII = "CN_VIII"
    CN_VIII_L = "CN_VIII_L"
    CN_VIII_R = "CN_VIII_R"
    CN_XI = "CN_XI"
    CN_XI_L = "CN_XI_L"
    CN_XI_R = "CN_XI_R"
    CN_XII = "CN_XII"
    CN_XII_L = "CN_XII_L"
    CN_XII_R = "CN_XII_R"
    Cochlea = "Cochlea"
    Cochlea_L = "Cochlea_L"
    Cochlea_R = "Cochlea_R"
    Colon = "Colon"
    Colon_Ascending = "Colon_Ascending"
    Colon_Decending = "Colon_Decending"
    Colon_PTVxx = "Colon_PTVxx"
    Colon_Sigmoid = "Colon_Sigmoid"
    Colon_Transverse = "Colon_Transverse"
    Cornea = "Cornea"
    Cornea_L = "Cornea_L"
    Cornea_R = "Cornea_R"
    CribriformPlate = "CribriformPlate"
    Cricoid = "Cricoid"
    Cricopharyngeus = "Cricopharyngeus"
    CTV = "CTV"
    Dens = "Dens"
    Diaphragm = "Diaphragm"
    Duodenum = "Duodenum"
    Ear_External_L = "Ear_External_L"
    Ear_External_R = "Ear_External_R"
    Ear_Externals = "Ear_Externals"
    Ear_Internal_L = "Ear_Internal_L"
    Ear_Internal_R = "Ear_Internal_R"
    Ear_Internals = "Ear_Internals"
    Ear_Middle = "Ear_Middle"
    Ear_Middle_L = "Ear_Middle_L"
    Ear_Middle_R = "Ear_Middle_R"
    Edema = "Edema"
    Elbow = "Elbow"
    Elbow_L = "Elbow_L"
    Elbow_R = "Elbow_R"
    E_PTV_Ev05_xxxx = "E-PTV_Ev05_xxxx"
    E_PTV_xxxx = "E-PTV_xxxx"
    Esophagus = "Esophagus"
    Esophagus_I = "Esophagus_I"
    Esophagus_M = "Esophagus_M"
    Esophagus_NAdj = "Esophagus_NAdj"
    Esophagus_S = "Esophagus_S"
    Eval = "Eval"
    External = "External"
    Eye_L = "Eye_L"
    Eye_R = "Eye_R"
    Eyes = "Eyes"
    Femur_Base_L = "Femur_Base_L"
    Femur_Base_R = "Femur_Base_R"
    Femur_Head_L = "Femur_Head_L"
    Femur_Head_R = "Femur_Head_R"
    Femur_Joint_L = "Femur_Joint_L"
    Femur_Joint_R = "Femur_Joint_R"
    Femur_L = "Femur_L"
    Femur_Neck_L = "Femur_Neck_L"
    Femur_Neck_R = "Femur_Neck_R"
    Femur_R = "Femur_R"
    Femur_Shaft_L = "Femur_Shaft_L"
    Femur_Shaft_R = "Femur_Shaft_R"
    Femurs = "Femurs"
    Fibula = "Fibula"
    Fibula_L = "Fibula_L"
    Fibula_R = "Fibula_R"
    Foley = "Foley"
    Fossa_Jugular = "Fossa_Jugular"
    Fossa_Posterior = "Fossa_Posterior"
    Gallbladder = "Gallbladder"
    Genitals = "Genitals"
    Glnd_Adrenal_L = "Glnd_Adrenal_L"
    Glnd_Adrenal_R = "Glnd_Adrenal_R"
    Glnd_Lacrimal = "Glnd_Lacrimal"
    Glnd_Lacrimal_L = "Glnd_Lacrimal_L"
    Glnd_Lacrimal_R = "Glnd_Lacrimal_R"
    Glnd_Parathyroid = "Glnd_Parathyroid"
    Glnd_Subling_L = "Glnd_Subling_L"
    Glnd_Subling_R = "Glnd_Subling_R"
    Glnd_Sublings = "Glnd_Sublings"
    Glnd_Submand_L = "Glnd_Submand_L"
    Glnd_Submand_R = "Glnd_Submand_R"
    Glnd_Submands = "Glnd_Submands"
    Glnd_Thymus = "Glnd_Thymus"
    Glnd_Thyroid = "Glnd_Thyroid"
    Glottis = "Glottis"
    GreatVes = "GreatVes"
    GreatVes_NAdj = "GreatVes_NAdj"
    GrowthPlate_L = "GrowthPlate_L"
    GrowthPlate_R = "GrowthPlate_R"
    GTV = "GTV"
    Hardpalate = "Hardpalate"
    Heart = "Heart"
    Hemisphere_L = "Hemisphere_L"
    Hemisphere_R = "Hemisphere_R"
    Hemispheres = "Hemispheres"
    Hippocampi = "Hippocampi"
    Hippocampus_L = "Hippocampus_L"
    Hippocampus_R = "Hippocampus_R"
    Humerus_L = "Humerus_L"
    Humerus_R = "Humerus_R"
    Hypothalmus = "Hypothalmus"
    Hypothalmus_PRV = "Hypothalmus_PRV"
    Hypothalmus_PRVx = "Hypothalmus_PRVx"
    IDL = "IDL"
    Ileum = "Ileum"
    ITV = "ITV"
    Jejunum = "Jejunum"
    Jejunum_Ileum = "Jejunum_Ileum"
    Joint_Elbow = "Joint_Elbow"
    Joint_Elbow_L = "Joint_Elbow_L"
    Joint_Elbow_R = "Joint_Elbow_R"
    Joint_Glenohum = "Joint_Glenohum"
    Joint_Glenohum_L = "Joint_Glenohum_L"
    Joint_Glenohum_R = "Joint_Glenohum_R"
    Joint_Surface = "Joint_Surface"
    Joint_TM = "Joint_TM"
    Joint_TM_L = "Joint_TM_L"
    Joint_TM_R = "Joint_TM_R"
    Kidney_Cortex = "Kidney_Cortex"
    Kidney_Cortex_L = "Kidney_Cortex_L"
    Kidney_Cortex_R = "Kidney_Cortex_R"
    Kidney_Hilum_L = "Kidney_Hilum_L"
    Kidney_Hilum_R = "Kidney_Hilum_R"
    Kidney_Hilums = "Kidney_Hilums"
    Kidney_L = "Kidney_L"
    Kidney_L_GTV = "Kidney_L-GTV"
    Kidney_Pelvis_L = "Kidney_Pelvis_L"
    Kidney_Pelvis_R = "Kidney_Pelvis_R"
    Kidney_R = "Kidney_R"
    Kidney_R_GTV = "Kidney_R-GTV"
    Kidney_GTV = "Kidney-GTV"
    Kidneys = "Kidneys"
    Knee = "Knee"
    Knee_L = "Knee_L"
    Knee_R = "Knee_R"
    Laryngl_Pharynx = "Laryngl_Pharynx"
    Larynx = "Larynx"
    Larynx_SG = "Larynx_SG"
    Leads = "Leads"
    Lens = "Lens"
    Lens_L = "Lens_L"
    Lens_R = "Lens_R"
    Lig_Hepatogastrc = "Lig_Hepatogastrc"
    Lips = "Lips"
    Liver = "Liver"
    Liver_CTV = "Liver-CTV"
    Liver_GTV = "Liver-GTV"
    LN = "LN"
    LN_Ax_Apical = "LN_Ax_Apical"
    LN_Ax_Apical_L = "LN_Ax_Apical_L"
    LN_Ax_Apical_R = "LN_Ax_Apical_R"
    LN_Ax_Central_L = "LN_Ax_Central_L"
    LN_Ax_Central_R = "LN_Ax_Central_R"
    LN_Ax_Centrals = "LN_Ax_Centrals"
    LN_Ax_L = "LN_Ax_L"
    LN_Ax_L1_L = "LN_Ax_L1_L"
    LN_Ax_L1_R = "LN_Ax_L1_R"
    LN_Ax_L2_L = "LN_Ax_L2_L"
    LN_Ax_L2_R = "LN_Ax_L2_R"
    LN_Ax_L3_L = "LN_Ax_L3_L"
    LN_Ax_L3_R = "LN_Ax_L3_R"
    LN_Ax_Lateral_L = "LN_Ax_Lateral_L"
    LN_Ax_Lateral_R = "LN_Ax_Lateral_R"
    LN_Ax_Laterals = "LN_Ax_Laterals"
    LN_Ax_Pectoral_L = "LN_Ax_Pectoral_L"
    LN_Ax_Pectoral_R = "LN_Ax_Pectoral_R"
    LN_Ax_Pectorals = "LN_Ax_Pectorals"
    LN_Ax_R = "LN_Ax_R"
    LN_Ax_Subscap_L = "LN_Ax_Subscap_L"
    LN_Ax_Subscap_R = "LN_Ax_Subscap_R"
    LN_Ax_Subscaps = "LN_Ax_Subscaps"
    LN_Brachioceph_L = "LN_Brachioceph_L"
    LN_Brachioceph_R = "LN_Brachioceph_R"
    LN_Brachiocephs = "LN_Brachiocephs"
    LN_Bronchpulm_L = "LN_Bronchpulm_L"
    LN_Bronchpulm_R = "LN_Bronchpulm_R"
    LN_Bronchpulms = "LN_Bronchpulms"
    LN_Diaphragmatic = "LN_Diaphragmatic"
    LN_Iliac_Ext_L = "LN_Iliac_Ext_L"
    LN_Iliac_Ext_R = "LN_Iliac_Ext_R"
    LN_Iliac_Int_L = "LN_Iliac_Int_L"
    LN_Iliac_L = "LN_Iliac_L"
    LN_Iliac_R = "LN_Iliac_R"
    LN_IMN_L = "LN_IMN_L"
    LN_IMN_R = "LN_IMN_R"
    LN_IMNs = "LN_IMNs"
    LN_Inguinofem = "LN_Inguinofem"
    LN_Inguinofem_L = "LN_Inguinofem_L"
    LN_Inguinofem_R = "LN_Inguinofem_R"
    LN_Intercostals = "LN_Intercostals"
    LN_L = "LN_L"
    LN_Ligamentarter = "LN_Ligamentarter"
    LN_lliac_Int_R = "LN_lliac_Int_R"
    LN_Mediastinals = "LN_Mediastinals"
    LN_Neck_IA_L = "LN_Neck_IA_L"
    LN_Neck_IA_R = "LN_Neck_IA_R"
    LN_Neck_IB_L = "LN_Neck_IB_L"
    LN_Neck_IB_R = "LN_Neck_IB_R"
    LN_Neck_II_L = "LN_Neck_II_L"
    LN_Neck_II_R = "LN_Neck_II_R"
    LN_Neck_IIA_L = "LN_Neck_IIA_L"
    LN_Neck_IIA_R = "LN_Neck_IIA_R"
    LN_Neck_IIB_L = "LN_Neck_IIB_L"
    LN_Neck_IIB_R = "LN_Neck_IIB_R"
    LN_Neck_III_L = "LN_Neck_III_L"
    LN_Neck_III_R = "LN_Neck_III_R"
    LN_Neck_IV_L = "LN_Neck_IV_L"
    LN_Neck_IV_R = "LN_Neck_IV_R"
    LN_Neck_V_L = "LN_Neck_V_L"
    LN_Neck_V_R = "LN_Neck_V_R"
    LN_Neck_VA_L = "LN_Neck_VA_L"
    LN_Neck_VA_R = "LN_Neck_VA_R"
    LN_Neck_VB_L = "LN_Neck_VB_L"
    LN_Neck_VB_R = "LN_Neck_VB_R"
    LN_Neck_VC_L = "LN_Neck_VC_L"
    LN_Neck_VC_R = "LN_Neck_VC_R"
    LN_Neck_VI_L = "LN_Neck_VI_L"
    LN_Neck_VI_R = "LN_Neck_VI_R"
    LN_Neck_VII_L = "LN_Neck_VII_L"
    LN_Neck_VII_R = "LN_Neck_VII_R"
    LN_Obturator_L = "LN_Obturator_L"
    LN_Obturator_R = "LN_Obturator_R"
    LN_Paraaortic = "LN_Paraaortic"
    LN_Paramammary_L = "LN_Paramammary_L"
    LN_Paramammary_R = "LN_Paramammary_R"
    LN_Paramammarys = "LN_Paramammarys"
    LN_Parasternal_L = "LN_Parasternal_L"
    LN_Parasternal_R = "LN_Parasternal_R"
    LN_Parasternals = "LN_Parasternals"
    LN_Pelvic_L = "LN_Pelvic_L"
    LN_Pelvic_R = "LN_Pelvic_R"
    LN_Pelvics = "LN_Pelvics"
    LN_Portahepatis = "LN_Portahepatis"
    LN_Presacral_L = "LN_Presacral_L"
    LN_Presacral_R = "LN_Presacral_R"
    LN_Pulmonary_L = "LN_Pulmonary_L"
    LN_Pulmonary_R = "LN_Pulmonary_R"
    LN_Pulmonarys = "LN_Pulmonarys"
    LN_R = "LN_R"
    LN_Sclav_L = "LN_Sclav_L"
    LN_Sclav_R = "LN_Sclav_R"
    LN_Supmammary_L = "LN_Supmammary_L"
    LN_Supmammary_R = "LN_Supmammary_R"
    LN_Supmammarys = "LN_Supmammarys"
    LN_Trachbrnchs = "LN_Trachbrnchs"
    LN_Trachbrnchs_L = "LN_Trachbrnchs_L"
    LN_Trachbrnchs_R = "LN_Trachbrnchs_R"
    Lobe_Frontal = "Lobe_Frontal"
    Lobe_Frontal_L = "Lobe_Frontal_L"
    Lobe_Frontal_R = "Lobe_Frontal_R"
    Lobe_Occipital = "Lobe_Occipital"
    Lobe_Occipital_L = "Lobe_Occipital_L"
    Lobe_Occipital_R = "Lobe_Occipital_R"
    Lobe_Parietal = "Lobe_Parietal"
    Lobe_Parietal_L = "Lobe_Parietal_L"
    Lobe_Parietal_R = "Lobe_Parietal_R"
    Lobe_Temporal = "Lobe_Temporal"
    Lobe_Temporal_L = "Lobe_Temporal_L"
    Lobe_Temporal_R = "Lobe_Temporal_R"
    Lung_L = "Lung_L"
    Lung_LLL = "Lung_LLL"
    Lung_LUL = "Lung_LUL"
    Lung_R = "Lung_R"
    Lung_RLL = "Lung_RLL"
    Lung_RML = "Lung_RML"
    Lung_RUL = "Lung_RUL"
    Lungs = "Lungs"
    Lungs_CTV = "Lungs-CTV"
    Lungs_GTV = "Lungs-GTV"
    Lungs_ITV = "Lungs-ITV"
    Lungs_PTV = "Lungs-PTV"
    Malleus = "Malleus"
    Malleus_L = "Malleus_L"
    Malleus_R = "Malleus_R"
    Markers = "Markers"
    Maxilla = "Maxilla"
    Maxilla_L = "Maxilla_L"
    Maxilla_R = "Maxilla_R"
    Mediastinum = "Mediastinum"
    Musc = "Musc"
    Musc_Constrict = "Musc_Constrict"
    Musc_Constrict_I = "Musc_Constrict_I"
    Musc_Constrict_M = "Musc_Constrict_M"
    Musc_Constrict_S = "Musc_Constrict_S"
    Musc_Digastric_L = "Musc_Digastric_L"
    Musc_Digastric_R = "Musc_Digastric_R"
    Musc_Masseter = "Musc_Masseter"
    Musc_Masseter_L = "Musc_Masseter_L"
    Musc_Masseter_R = "Musc_Masseter_R"
    Musc_Platysma_L = "Musc_Platysma_L"
    Musc_Platysma_R = "Musc_Platysma_R"
    Musc_Pterygoid_L = "Musc_Pterygoid_L"
    Musc_Pterygoid_R = "Musc_Pterygoid_R"
    Musc_Sclmast_L = "Musc_Sclmast_L"
    Musc_Sclmast_R = "Musc_Sclmast_R"
    Musc_Temporal_L = "Musc_Temporal_L"
    Musc_Temporal_R = "Musc_Temporal_R"
    Nasalconcha_LI = "Nasalconcha_LI"
    Nasalconcha_RI = "Nasalconcha_RI"
    Nasopharynx = "Nasopharynx"
    Nose = "Nose"
    Nrv_Peripheral = "Nrv_Peripheral"
    Nrv_Root = "Nrv_Root"
    OpticChiasm = "OpticChiasm"
    OpticChiasm_PRV = "OpticChiasm_PRV"
    OpticChiasm_PRVx = "OpticChiasm_PRVx"
    OpticNrv = "OpticNrv"
    OpticNrv_L = "OpticNrv_L"
    OpticNrv_PRV = "OpticNrv_PRV"
    OpticNrv_PRV_L = "OpticNrv_PRV_L"
    OpticNrv_PRV_R = "OpticNrv_PRV_R"
    OpticNrv_PRVxx_L = "OpticNrv_PRVxx_L"
    OpticNrv_PRVxx_R = "OpticNrv_PRVxx_R"
    OpticNrv_R = "OpticNrv_R"
    Orbit_L = "Orbit_L"
    Orbit_R = "Orbit_R"
    Oropharynx = "Oropharynx"
    Ovaries = "Ovaries"
    Ovary_L = "Ovary_L"
    Ovary_R = "Ovary_R"
    Pacemaker = "Pacemaker"
    Palate_Soft = "Palate_Soft"
    PancJejuno = "PancJejuno"
    Pancreas = "Pancreas"
    Pancreas_Head = "Pancreas_Head"
    Pancreas_Tail = "Pancreas_Tail"
    Parametrium = "Parametrium"
    Parotid_L = "Parotid_L"
    Parotid_R = "Parotid_R"
    Parotids = "Parotids"
    PenileBulb = "PenileBulb"
    Penis = "Penis"
    Pericardium = "Pericardium"
    Perineum = "Perineum"
    Peritoneum = "Peritoneum"
    Pharynx = "Pharynx"
    Pineal = "Pineal"
    Pituitary = "Pituitary"
    Pituitary_PRVxx = "Pituitary_PRVxx"
    Pons = "Pons"
    Postop = "Postop"
    Preop = "Preop"
    Proc_Condyloid_L = "Proc_Condyloid_L"
    Proc_Condyloid_R = "Proc_Condyloid_R"
    Proc_Coronoid_L = "Proc_Coronoid_L"
    Proc_Coronoid_R = "Proc_Coronoid_R"
    Prostate = "Prostate"
    ProstateBed = "ProstateBed"
    Prosthesis = "Prosthesis"
    Pterygoid_Lat_L = "Pterygoid_Lat_L"
    Pterygoid_Lat_R = "Pterygoid_Lat_R"
    Pterygoid_Med_L = "Pterygoid_Med_L"
    Pterygoid_Med_R = "Pterygoid_Med_R"
    PTV = "PTV"
    PubicSymphys = "PubicSymphys"
    PubicSymphys_L = "PubicSymphys_L"
    PubicSymphys_R = "PubicSymphys_R"
    Radius_L = "Radius_L"
    Radius_R = "Radius_R"
    Rectal_Wall = "Rectal_Wall"
    Rectum = "Rectum"
    Retina_L = "Retina_L"
    Retina_PRVxx_L = "Retina_PRVxx_L"
    Retina_PRVxx_R = "Retina_PRVxx_R"
    Retina_R = "Retina_R"
    Retinas = "Retinas"
    Rib = "Rib"
    Rib01_L = "Rib01_L"
    Rib01_R = "Rib01_R"
    Rib02_L = "Rib02_L"
    Rib02_R = "Rib02_R"
    Rib03_L = "Rib03_L"
    Rib03_R = "Rib03_R"
    Rib04_L = "Rib04_L"
    Rib04_R = "Rib04_R"
    Rib05_L = "Rib05_L"
    Rib05_R = "Rib05_R"
    Rib06_L = "Rib06_L"
    Rib06_R = "Rib06_R"
    Rib07_L = "Rib07_L"
    Rib07_R = "Rib07_R"
    Rib08_L = "Rib08_L"
    Rib08_R = "Rib08_R"
    Rib09_L = "Rib09_L"
    Rib09_R = "Rib09_R"
    Rib10_L = "Rib10_L"
    Rib10_R = "Rib10_R"
    Rib11_L = "Rib11_L"
    Rib11_R = "Rib11_R"
    Rib12_L = "Rib12_L"
    Rib12_R = "Rib12_R"
    SacralPlex = "SacralPlex"
    Sacrum = "Sacrum"
    Scalp = "Scalp"
    Scapula_L = "Scapula_L"
    Scapula_R = "Scapula_R"
    Scar = "Scar"
    Scar_Boost = "Scar_Boost"
    Scrotum = "Scrotum"
    SeminalVes = "SeminalVes"
    SeminalVes_Dist = "SeminalVes_Dist"
    SeminalVes_Prox = "SeminalVes_Prox"
    Sinus_Ethmoid = "Sinus_Ethmoid"
    Sinus_Frontal = "Sinus_Frontal"
    Sinus_Frontal_L = "Sinus_Frontal_L"
    Sinus_Frontal_R = "Sinus_Frontal_R"
    Sinus_Maxilry = "Sinus_Maxilry"
    Sinus_Maxilry_L = "Sinus_Maxilry_L"
    Sinus_Maxilry_R = "Sinus_Maxilry_R"
    Sinus_Sphenoid = "Sinus_Sphenoid"
    Sinus_Sphenoid_L = "Sinus_Sphenoid_L"
    Sinus_Sphenoid_R = "Sinus_Sphenoid_R"
    Skin = "Skin"
    Skin_Perineum = "Skin_Perineum"
    Skin_Peritoneum = "Skin_Peritoneum"
    Skull = "Skull"
    Spc = "Spc"
    Spc_Bowel = "Spc_Bowel"
    Spc_Bowel_Small = "Spc_Bowel_Small"
    Spc_Retrophar_L = "Spc_Retrophar_L"
    Spc_Retrophar_R = "Spc_Retrophar_R"
    Spc_Retrophars = "Spc_Retrophars"
    Spc_Retrosty = "Spc_Retrosty"
    Spc_Retrosty_L = "Spc_Retrosty_L"
    Spc_Retrosty_R = "Spc_Retrosty_R"
    Spc_Supraclav_L = "Spc_Supraclav_L"
    Spc_Supraclav_R = "Spc_Supraclav_R"
    Sphincter_Anal = "Sphincter_Anal"
    SpinalCanal = "SpinalCanal"
    SpinalCanal_PRV = "SpinalCanal_PRV"
    SpinalCanal_PRVx = "SpinalCanal_PRVx"
    SpinalCord = "SpinalCord"
    SpinalCord_Cerv = "SpinalCord_Cerv"
    SpinalCord_Lum = "SpinalCord_Lum"
    SpinalCord_PRV = "SpinalCord_PRV"
    SpinalCord_PRVxx = "SpinalCord_PRVxx"
    SpinalCord_Sac = "SpinalCord_Sac"
    SpinalCord_Thor = "SpinalCord_Thor"
    Spleen = "Spleen"
    Spleen_Hilum = "Spleen_Hilum"
    Spongiosum = "Spongiosum"
    Stapes = "Stapes"
    Stapes_L = "Stapes_L"
    Stapes_R = "Stapes_R"
    Stomach = "Stomach"
    Stomach_PRVxx = "Stomach_PRVxx"
    Strct = "Strct"
    Strct_Suprapatel = "Strct_Suprapatel"
    Surf_Eye = "Surf_Eye"
    SurgicalBed = "SurgicalBed"
    Sys_Ventricular = "Sys_Ventricular"
    Tendon = "Tendon"
    Tendon_Quad = "Tendon_Quad"
    Testis = "Testis"
    Testis_L = "Testis_L"
    Testis_R = "Testis_R"
    ThecalSac = "ThecalSac"
    Thoracic_Duct = "Thoracic_Duct"
    Tongue = "Tongue"
    Tongue_All = "Tongue_All"
    Tongue_Base = "Tongue_Base"
    Tongue_Base_L = "Tongue_Base_L"
    Tongue_Base_R = "Tongue_Base_R"
    Tongue_Oral = "Tongue_Oral"
    Tongue_Oral_L = "Tongue_Oral_L"
    Tongue_Oral_R = "Tongue_Oral_R"
    Tonsil = "Tonsil"
    Trachea = "Trachea"
    Trachea_NAdj = "Trachea_NAdj"
    TumorBed = "TumorBed"
    Ureter_L = "Ureter_L"
    Ureter_R = "Ureter_R"
    UreterDivert = "UreterDivert"
    Ureters = "Ureters"
    Urethra = "Urethra"
    Urethra_Prostatc = "Urethra_Prostatc"
    Uterus = "Uterus"
    V_Azygos = "V_Azygos"
    V_Brachioceph_L = "V_Brachioceph_L"
    V_Brachioceph_R = "V_Brachioceph_R"
    V_Iliac_Ext_L = "V_Iliac_Ext_L"
    V_Iliac_Ext_R = "V_Iliac_Ext_R"
    V_Iliac_Int_L = "V_Iliac_Int_L"
    V_Iliac_Int_R = "V_Iliac_Int_R"
    V_Iliac_L = "V_Iliac_L"
    V_Iliac_R = "V_Iliac_R"
    V_Jugular = "V_Jugular"
    V_Jugular_Ext_L = "V_Jugular_Ext_L"
    V_Jugular_Ext_R = "V_Jugular_Ext_R"
    V_Jugular_Int_L = "V_Jugular_Int_L"
    V_Jugular_Int_R = "V_Jugular_Int_R"
    V_Portal = "V_Portal"
    V_Pulmonary = "V_Pulmonary"
    V_Subclavian_L = "V_Subclavian_L"
    V_Subclavian_R = "V_Subclavian_R"
    V_Subclavians = "V_Subclavians"
    V_Venacava_I = "V_Venacava_I"
    V_Venacava_S = "V_Venacava_S"
    Vagina = "Vagina"
    Vagina_Surf = "Vagina_Surf"
    VaginalCuff = "VaginalCuff"
    Valve = "Valve"
    Valve_Aortic = "Valve_Aortic"
    Valve_Mitral = "Valve_Mitral"
    Valve_Pulmonic = "Valve_Pulmonic"
    Valve_Tricuspid = "Valve_Tricuspid"
    VB = "VB"
    VB_C = "VB_C"
    VB_C1 = "VB_C1"
    VB_C2 = "VB_C2"
    VB_C3 = "VB_C3"
    VB_C4 = "VB_C4"
    VB_C5 = "VB_C5"
    VB_C6 = "VB_C6"
    VB_C7 = "VB_C7"
    VB_L = "VB_L"
    VB_L1 = "VB_L1"
    VB_L2 = "VB_L2"
    VB_L3 = "VB_L3"
    VB_L4 = "VB_L4"
    VB_L5 = "VB_L5"
    VB_S = "VB_S"
    VB_S1 = "VB_S1"
    VB_S2 = "VB_S2"
    VB_S3 = "VB_S3"
    VB_S4 = "VB_S4"
    VB_S5 = "VB_S5"
    VB_T = "VB_T"
    VB_T01 = "VB_T01"
    VB_T02 = "VB_T02"
    VB_T03 = "VB_T03"
    VB_T04 = "VB_T04"
    VB_T05 = "VB_T05"
    VB_T06 = "VB_T06"
    VB_T07 = "VB_T07"
    VB_T08 = "VB_T08"
    VB_T09 = "VB_T09"
    VB_T10 = "VB_T10"
    VB_T11 = "VB_T11"
    VB_T12 = "VB_T12"
    VBs = "VBs"
    Ventricle = "Ventricle"
    Ventricle_L = "Ventricle_L"
    Ventricle_R = "Ventricle_R"
    VocalCord_L = "VocalCord_L"
    VocalCord_R = "VocalCord_R"
    VocalCords = "VocalCords"
    Vomer = "Vomer"
    Vulva = "Vulva"
    Wall_Vagina = "Wall_Vagina"
